@@ -18,10 +18,9 @@ import os
 import getpass
 import threading
 import subprocess
-import shlex
 from collections import namedtuple
 from copy import deepcopy
-from hashlib import sha256
+from hashlib import sha1
 import json
 
 from dateutil.parser import parse
@@ -30,6 +29,7 @@ from dateutil.tz import tzlocal
 import botocore.configloader
 import botocore.compat
 from botocore.compat import total_seconds
+from botocore.compat import compat_shell_split
 from botocore.exceptions import UnknownCredentialError
 from botocore.exceptions import PartialCredentialsError
 from botocore.exceptions import ConfigNotFound
@@ -495,6 +495,11 @@ class CachedCredentialFetcher(object):
     def _create_cache_key(self):
         raise NotImplementedError('_create_cache_key()')
 
+    def _make_file_safe(self, filename):
+        # Replace :, path sep, and / to make it the string filename safe.
+        filename = filename.replace(':', '_').replace(os.path.sep, '_')
+        return filename.replace('/', '_')
+
     def _get_credentials(self):
         raise NotImplementedError('_get_credentials()')
 
@@ -624,12 +629,8 @@ class AssumeRoleCredentialFetcher(CachedCredentialFetcher):
             args['Policy'] = json.loads(args['Policy'])
 
         args = json.dumps(args, sort_keys=True)
-        argument_hash = sha256(args.encode('utf-8')).hexdigest()
-
-        # Prefix the cache key with the role arn to aid human-readability.
-        # Replace : and path sep to make it file safe.
-        arn = self._role_arn.replace(':', '_').replace(os.path.sep, '_')
-        return '%s--%s' % (arn, argument_hash)
+        argument_hash = sha1(args.encode('utf-8')).hexdigest()
+        return self._make_file_safe(argument_hash)
 
     def _get_credentials(self):
         """Get credentials by calling assume role."""
@@ -740,7 +741,7 @@ class ProcessProvider(CredentialProvider):
     def _retrieve_credentials_using(self, credential_process):
         # We're not using shell=True, so we need to pass the
         # command and all arguments as a list.
-        process_list = shlex.split(credential_process)
+        process_list = compat_shell_split(credential_process)
         p = self._popen(process_list,
                         stdout=subprocess.PIPE,
                         stderr=subprocess.PIPE)
